@@ -360,6 +360,12 @@ static GdkPixbuf* notification_trayicon_create(void)
 {
   GdkPixbuf *trayicon_nomail;
 	GtkActionGroup *action_group;
+#ifdef ENABLE_NLS
+	char *tdomain = strdup(textdomain(NULL)); /* Store current translation domain. */
+
+	/* Set our gettext translation domain for menuitems below. */
+	textdomain(TEXTDOMAIN);
+#endif
 
   trayicon_nomail = notification_pixbuf_get(NOTIFICATION_TRAYICON_NOMAIL);
 
@@ -398,6 +404,12 @@ static GdkPixbuf* notification_trayicon_create(void)
 	traymenu_popup = gtk_menu_item_get_submenu(GTK_MENU_ITEM(
 				gtk_ui_manager_get_widget(gtkut_ui_manager(), "/Menus/SysTrayiconPopup")));
 
+#ifdef ENABLE_NLS
+	/* Restore previous translation domain, as to not break stuff. */
+	textdomain(tdomain);
+	g_free(tdomain);
+#endif
+
   return trayicon_nomail;
 }
 
@@ -852,7 +864,7 @@ static gchar* notification_trayicon_popup_assemble_body(MsgInfo *msginfo)
     utf8_str = g_strdup("");
 
     if(popup.num_mail) {
-      msg = g_strdup_printf(ngettext("%d new mail message arrived",
+      msg = g_strdup_printf(dngettext(TEXTDOMAIN, "%d new mail message arrived",
 		      		     "%d new mail messages arrived",
 		            popup.num_mail),
 			    popup.num_mail);
@@ -863,7 +875,7 @@ static gchar* notification_trayicon_popup_assemble_body(MsgInfo *msginfo)
       str_empty = FALSE;
     }
     if(popup.num_news) {
-      msg = g_strdup_printf(ngettext("%d new news post arrived",
+      msg = g_strdup_printf(dngettext(TEXTDOMAIN, "%d new news post arrived",
 		      		     "%d new news posts arrived",
 		            popup.num_news),
 			    popup.num_news);
@@ -874,7 +886,7 @@ static gchar* notification_trayicon_popup_assemble_body(MsgInfo *msginfo)
       str_empty = FALSE;
     }
     if(popup.num_calendar) {
-      msg = g_strdup_printf(ngettext("%d new calendar message arrived",
+      msg = g_strdup_printf(dngettext(TEXTDOMAIN, "%d new calendar message arrived",
 		      		     "%d new calendar messages arrived",
 		            popup.num_calendar),
 			    popup.num_calendar);
@@ -885,7 +897,7 @@ static gchar* notification_trayicon_popup_assemble_body(MsgInfo *msginfo)
       str_empty = FALSE;
     }
     if(popup.num_rss) {
-      msg = g_strdup_printf(ngettext("%d new article in RSS feeds arrived",
+      msg = g_strdup_printf(dngettext(TEXTDOMAIN, "%d new article in RSS feeds arrived",
 		      		     "%d new articles in RSS feeds arrived",
 		            popup.num_rss),
 			    popup.num_rss);
