@@ -3,6 +3,6 @@
 
 gchar *rssyl_strreplace(gchar *source, gchar *pattern,
 		gchar *replacement);
-gchar *rssyl_sanitize_string(gchar *str);
+gchar *rssyl_sanitize_string(gchar *str, gboolean strip_nl);
 
 #endif /* __STRREPLACE_H */
